==> jec-glasscat-core-0.1.1.tgz: package/src/com/onsoft/glasscat/domains/errors/DomainRequestError.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2017 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

/**
 * A basic Data Transfert Object for propagating domain container transaction
 * errors through a GlassCat application.
 */
export class DomainRequestError {

  //////////////////////////////////////////////////////////////////////////////
  // Constructor function
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Creates a new <code>DomainRequestError</code> instance.
   */
  constructor() {}

  //////////////////////////////////////////////////////////////////////////////
  // Public properties
  //////////////////////////////////////////////////////////////////////////////

  /**
   * The HTTP status code associated with this error.
   */
  public statusCode:number = -1;

  /**
   * The details code associated with this error.
   */
  public detailsCode:string = "httpErrors.error.description";

  /**
   * The message associated with this error.
   */
  public message:string = null;
}

==> jec-glasscat-core-0.1.8.tgz: package/src/com/onsoft/glasscat/domains/errors/DomainRequestError.ts <==
//  DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
//
//   Copyright 2016-2018 Pascal ECHEMANN.
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import {HttpStatusCode} from "jec-commons";

/**
 * A basic Data Transfert Object for propagating domain container transaction
 * errors through a GlassCat application.
 */
export class DomainRequestError {

  //////////////////////////////////////////////////////////////////////////////
  // Constructor function
  //////////////////////////////////////////////////////////////////////////////

  /**
   * Creates a new <code>DomainRequestError</code> instance.
   */
  constructor() {}

  //////////////////////////////////////////////////////////////////////////////
  // Public properties
  //////////////////////////////////////////////////////////////////////////////

  /**
   * The HTTP status code associated with this error.
   */
  public statusCode:HttpStatusCode = null;

  /**
   * The details code associated with this error.
   */
  public detailsCode:string = "httpErrors.error.description";

  /**
   * The message associated with this error.
   */
  public message:string = null;
}
